<?php
/**
 * This file is part of the FIREGENTO project.
 *
 * FireGento_MageSetup is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This script is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * PHP version 5
 *
 * @category  FireGento
 * @package   FireGento_MageSetup
 * @author    FireGento Team <team@firegento.com>
 * @copyright 2013 FireGento Team (http://www.firegento.de). All rights served.
 * @license   http://opensource.org/licenses/gpl-3.0 GNU General Public License, version 3 (GPLv3)
 * @version   $Id:$
 * @since     0.1.0
 */
/**
 * Tax Source model for existing customer tax classes
 *
 * @category  FireGento
 * @package   FireGento_MageSetup
 * @author    FireGento Team <team@firegento.com>
 * @copyright 2013 FireGento Team (http://www.firegento.de). All rights served.
 * @license   http://opensource.org/licenses/gpl-3.0 GNU General Public License, version 3 (GPLv3)
 * @version   $Id:$
 * @since     2.0.0
 */
class FireGento_MageSetup_Model_Source_Tax_CustomerTaxClass extends Mage_Tax_Model_Class_Source_Customer
{
    /**
     * Retrieve all product tax classes as array
     *
     * @param  bool $withEmpty Flag if an empty option should be prepended to the option array
     * @return array Product tax class option array
     */
    public function getAllOptions($withEmpty = false)
    {
        $options = parent::getAllOptions($withEmpty);
        foreach ($options as $optionKey => $option) {
            if (intval($option['value']) <= 0) {
                continue;
            }

            /* @var $customerGroupCollection Mage_Customer_Model_Resource_Group_Collection */
            $customerGroupCollection = Mage::getModel('customer/group')
                ->getCollection()
                ->addFieldToFilter('tax_class_id', $option['value'])
                ->setPageSize(1);

            if (!$customerGroupCollection->getSize()) {
                unset($options[$optionKey]);
            }
        }

        return $options;
    }
}
